@@ -9,17 +9,21 @@
 
 from preggy import expect
 
+from tests import Comparable
+
 #-----------------------------------------------------------------------------
 
 class FakeClass(object): pass
 class Other(FakeClass):  pass
-
+class Another(FakeClass, Comparable): pass
 
 TEST_DATA = frozenset([
     FakeClass,
     FakeClass(),
     Other,
-    Other()
+    Other(),
+    Another,
+    Another()
 ])
 
 #-----------------------------------------------------------------------------
